@@ -6,6 +6,7 @@ from .helpers.kafka_producer import Producer
 from .helpers.topics import Topics
 from .helpers.micro_fetcher import MicroFetcher
 from .helpers.atomic_transactions import Transactions
+from .helpers.atomic_transactions_v2 import Transactions as TransactionV2
 from .helpers.auth import Auth
 from .helpers.enums import Service
 from .helpers.database.base_model import init_base_model
@@ -20,6 +21,7 @@ __all__ = [
     "Topics",
     "MicroFetcher",
     "Transactions",
+    "TransactionV2",
     "Service",
     "Auth",
     "init_base_model",
