@@ -34,17 +34,11 @@ def serializer(schema=None, many=False):
                 client_data = dict()
 
                 content_type = request.headers.get('Content-Type')
-                if (content_type == 'application/json'):
+                if 'application/json' in content_type:
                     # if the request have json payload, the user need to send the Content-Type as application/json
                     client_data = request.json
                 elif request.form:
                     client_data = request.form.to_dict()
-                    for key, value in client_data.items():
-                        try:
-                            # look for strings like objects to convert them to python objects
-                            client_data[key] = json.loads(value)
-                        except json.JSONDecodeError as e:
-                            pass
 
                 if request.args:
                     client_data.update(request.args.to_dict())
