@@ -28,8 +28,8 @@ class QueryTypes(Enum):
 
 
 class InstallmentType(Enum):
-    LEASE = 1
-    PERSONAL_LOAN = 2
+    LEASE = 'Lease'
+    PERSONAL_LOAN = 'Personal Loan'
 
 
 def list_enum_values(enum_type):
